@@ -1,36 +1,36 @@
 package cmd
 
 import (
+	"fmt"
 	"os"
 
-	"github.com/apex/log"
-	"github.com/fatih/color"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/static"
-	"github.com/muesli/coral"
+	"github.com/spf13/cobra"
 )
 
 type initCmd struct {
-	cmd    *coral.Command
+	cmd    *cobra.Command
 	config string
 }
 
 func newInitCmd() *initCmd {
 	root := &initCmd{}
-	cmd := &coral.Command{
+	cmd := &cobra.Command{
 		Use:           "init",
 		Aliases:       []string{"i"},
 		Short:         "Generates a .goreleaser.yaml file",
 		SilenceUsage:  true,
 		SilenceErrors: true,
-		Args:          coral.NoArgs,
-		RunE: func(cmd *coral.Command, args []string) error {
+		Args:          cobra.NoArgs,
+		RunE: func(cmd *cobra.Command, args []string) error {
 			conf, err := os.OpenFile(root.config, os.O_WRONLY|os.O_CREATE|os.O_TRUNC|os.O_EXCL, 0o644)
 			if err != nil {
 				return err
 			}
 			defer conf.Close()
 
-			log.Infof(color.New(color.Bold).Sprintf("Generating %s file", root.config))
+			log.Infof(boldStyle.Render(fmt.Sprintf("Generating %s file", root.config)))
 			if _, err := conf.WriteString(static.ExampleConfig); err != nil {
 				return err
 			}
