@@ -6,11 +6,9 @@ import (
 	"fmt"
 	"os"
 	"os/exec"
-	"regexp"
 	"strings"
 
-	"github.com/apex/log"
-	"github.com/fatih/color"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/pkg/config"
 )
 
@@ -55,13 +53,6 @@ func matrix(build config.Build, version []byte) ([]string, error) {
 		if target.amd64 != "" && !contains(target.amd64, validGoamd64) {
 			return result, fmt.Errorf("invalid goamd64: %s", target.amd64)
 		}
-		if target.os == "windows" && target.arch == "arm64" && !go117re.Match(version) {
-			log.Warn(color.New(color.Bold, color.FgHiYellow).Sprintf(
-				"DEPRECATED: skipped windows/arm64 build on Go < 1.17 for compatibility, check %s for more info.",
-				"https://goreleaser.com/deprecations/#builds-for-windowsarm64",
-			))
-			continue
-		}
 		if !valid(target) {
 			log.WithField("target", target).Debug("skipped invalid build")
 			continue
@@ -144,8 +135,6 @@ func ignored(build config.Build, target target) bool {
 	return false
 }
 
-var go117re = regexp.MustCompile(`go version go1.1[7-9]`)
-
 func goVersion(build config.Build) ([]byte, error) {
 	cmd := exec.Command(build.GoBinary, "version")
 	// If the build.Dir is acessible, set the cmd dir to it in case
