@@ -6,8 +6,7 @@ import (
 	"strconv"
 	"testing"
 
-	"github.com/apex/log"
-	"github.com/apex/log/handlers/cli"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/golden"
 	"github.com/stretchr/testify/require"
 )
@@ -17,10 +16,10 @@ func TestWriter(t *testing.T) {
 		for _, out := range []Output{Info, Error} {
 			t.Run(strconv.Itoa(int(out)), func(t *testing.T) {
 				t.Cleanup(func() {
-					cli.Default.Writer = os.Stderr
+					log.Log = log.New(os.Stderr)
 				})
 				var b bytes.Buffer
-				cli.Default.Writer = &b
+				log.Log = log.New(&b)
 				l, err := NewWriter(log.Fields{"foo": "bar"}, out).Write([]byte("foo\nbar\n"))
 				require.NoError(t, err)
 				require.Equal(t, 8, l)
@@ -33,12 +32,11 @@ func TestWriter(t *testing.T) {
 		for _, out := range []Output{Info, Error} {
 			t.Run(strconv.Itoa(int(out)), func(t *testing.T) {
 				t.Cleanup(func() {
-					cli.Default.Writer = os.Stderr
-					log.SetLevel(log.InfoLevel)
+					log.Log = log.New(os.Stderr)
 				})
-				log.SetLevel(log.DebugLevel)
 				var b bytes.Buffer
-				cli.Default.Writer = &b
+				log.Log = log.New(&b)
+				log.SetLevel(log.DebugLevel)
 				l, err := NewWriter(log.Fields{"foo": "bar"}, out).Write([]byte("foo\nbar\n"))
 				require.NoError(t, err)
 				require.Equal(t, 8, l)
