@@ -8,7 +8,7 @@ import (
 	"path"
 	"strings"
 
-	"github.com/apex/log"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/extrafiles"
 	"github.com/goreleaser/goreleaser/internal/semerrgroup"
@@ -232,11 +232,9 @@ func (u *productionUploader) Upload(ctx *context.Context, filepath string, data
 	if err != nil {
 		return err
 	}
-	defer func() {
-		if cerr := w.Close(); err == nil {
-			err = cerr
-		}
-	}()
-	_, err = w.Write(data)
-	return err
+	defer func() { _ = w.Close() }()
+	if _, err = w.Write(data); err != nil {
+		return err
+	}
+	return w.Close()
 }
