@@ -9,7 +9,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/apex/log"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/internal/testlib"
@@ -655,8 +655,10 @@ func TestRunPipe(t *testing.T) {
 			expect: []string{
 				registry + "goreleaser/test_run_pipe:latest",
 			},
-			assertImageLabels: noLabels,
-			assertError:       testlib.AssertSkipped,
+			assertImageLabels:   noLabels,
+			assertError:         shouldNotErr,
+			pubAssertError:      testlib.AssertSkipped,
+			manifestAssertError: shouldNotErr,
 		},
 		"one_img_error_with_skip_push": {
 			dockers: []config.Docker{
@@ -839,8 +841,10 @@ func TestRunPipe(t *testing.T) {
 				registry + "goreleaser/mybin:v1.0.0-123",
 				registry + "goreleaser/mybin:latest",
 			},
-			assertImageLabels: noLabels,
-			assertError:       testlib.AssertSkipped,
+			assertImageLabels:   noLabels,
+			assertError:         shouldNotErr,
+			pubAssertError:      testlib.AssertSkipped,
+			manifestAssertError: shouldNotErr,
 		},
 		"no_permissions": {
 			dockers: []config.Docker{
@@ -1118,7 +1122,7 @@ func TestBuildCommand(t *testing.T) {
 			name:   "buildx",
 			buildx: true,
 			flags:  []string{"--label=foo", "--build-arg=bar=baz"},
-			expect: []string{"buildx", "build", ".", "--load", "-t", images[0], "-t", images[1], "--label=foo", "--build-arg=bar=baz"},
+			expect: []string{"buildx", "--builder", "default", "build", ".", "--load", "-t", images[0], "-t", images[1], "--label=foo", "--build-arg=bar=baz"},
 		},
 	}
 	for _, tt := range tests {
@@ -1372,6 +1376,14 @@ func TestSkip(t *testing.T) {
 			require.True(t, Pipe{}.Skip(context.New(config.Project{})))
 		})
 
+		t.Run("skip docker", func(t *testing.T) {
+			ctx := context.New(config.Project{
+				Dockers: []config.Docker{{}},
+			})
+			ctx.SkipDocker = true
+			require.True(t, Pipe{}.Skip(ctx))
+		})
+
 		t.Run("dont skip", func(t *testing.T) {
 			ctx := context.New(config.Project{
 				Dockers: []config.Docker{{}},
@@ -1385,6 +1397,14 @@ func TestSkip(t *testing.T) {
 			require.True(t, ManifestPipe{}.Skip(context.New(config.Project{})))
 		})
 
+		t.Run("skip docker", func(t *testing.T) {
+			ctx := context.New(config.Project{
+				DockerManifests: []config.DockerManifest{{}},
+			})
+			ctx.SkipDocker = true
+			require.True(t, ManifestPipe{}.Skip(ctx))
+		})
+
 		t.Run("dont skip", func(t *testing.T) {
 			ctx := context.New(config.Project{
 				DockerManifests: []config.DockerManifest{{}},
