@@ -5,7 +5,7 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/apex/log"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/ids"
 	"github.com/goreleaser/goreleaser/internal/pipe"
@@ -19,8 +19,10 @@ import (
 // allowing to publish multi-arch docker images.
 type ManifestPipe struct{}
 
-func (ManifestPipe) String() string                 { return "docker manifests" }
-func (ManifestPipe) Skip(ctx *context.Context) bool { return len(ctx.Config.DockerManifests) == 0 }
+func (ManifestPipe) String() string { return "docker manifests" }
+func (ManifestPipe) Skip(ctx *context.Context) bool {
+	return len(ctx.Config.DockerManifests) == 0 || ctx.SkipDocker
+}
 
 // Default sets the pipe defaults.
 func (ManifestPipe) Default(ctx *context.Context) error {
