@@ -24,29 +24,7 @@ func TestDefault(t *testing.T) {
 
 	ctx := &context.Context{
 		TokenType: context.TokenTypeGitHub,
-		Config: config.Project{
-			ProjectName: "barr",
-			Builds: []config.Build{
-				{
-					Binary: "foo",
-					Goos:   []string{"linux", "darwin"},
-					Goarch: []string{"386", "amd64"},
-				},
-				{
-					Binary: "bar",
-					Goos:   []string{"linux", "darwin"},
-					Goarch: []string{"386", "amd64"},
-					Ignore: []config.IgnoredBuild{
-						{Goos: "darwin", Goarch: "amd64"},
-					},
-				},
-				{
-					Binary: "foobar",
-					Goos:   []string{"linux"},
-					Goarch: []string{"amd64"},
-				},
-			},
-		},
+		Config:    config.Project{ProjectName: "barr"},
 	}
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ctx.Config.ProjectName, ctx.Config.Scoop.Name)
@@ -100,20 +78,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -128,7 +93,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -148,20 +113,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz", WrapInDirectory: "true"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -176,10 +128,11 @@ func Test_doRun(t *testing.T) {
 			},
 			[]artifact.Artifact{
 				{
-					Name:   "foo_1.0.1_windows_amd64.tar.gz",
-					Goos:   "windows",
-					Goarch: "amd64",
-					Path:   file,
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
 					Extra: map[string]interface{}{
 						"Wrap": "foo_1.0.1_windows_amd64",
 					},
@@ -208,21 +161,8 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						GitHubURLs: config.GitHubURLs{Download: "https://api.custom.github.enterprise.com"},
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
+						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.github.enterprise.com"},
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -236,7 +176,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -256,20 +196,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitLab: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -284,10 +211,11 @@ func Test_doRun(t *testing.T) {
 			},
 			[]artifact.Artifact{
 				{
-					Name:   "foo_1.0.1_windows_amd64.tar.gz",
-					Goos:   "windows",
-					Goarch: "amd64",
-					Path:   file,
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
 				},
 				{
 					Name:   "foo_1.0.1_windows_386.tar.gz",
@@ -310,21 +238,8 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						GitHubURLs: config.GitHubURLs{Download: "https://api.custom.gitlab.enterprise.com"},
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
+						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.gitlab.enterprise.com"},
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -339,10 +254,11 @@ func Test_doRun(t *testing.T) {
 			},
 			[]artifact.Artifact{
 				{
-					Name:   "foo_1.0.1_windows_amd64.tar.gz",
-					Goos:   "windows",
-					Goarch: "amd64",
-					Path:   file,
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
 				},
 				{
 					Name:   "foo_1.0.1_windows_386.tar.gz",
@@ -365,20 +281,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test"},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -391,11 +294,8 @@ func Test_doRun(t *testing.T) {
 				},
 				client.NewMock(),
 			},
-			[]artifact.Artifact{
-				{Name: "foo_1.0.1_linux_amd64.tar.gz", Goos: "linux", Goarch: "amd64"},
-				{Name: "foo_1.0.1_linux_386.tar.gz", Goos: "linux", Goarch: "386"},
-			},
-			shouldErr("scoop requires a windows build"),
+			[]artifact.Artifact{},
+			shouldErr(ErrNoWindows.Error()),
 			shouldNotErr,
 			noAssertions,
 		},
@@ -409,14 +309,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
 						Release: config.Release{
 							Draft: true,
 						},
@@ -433,7 +326,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -456,20 +349,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1-pre.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							SkipUpload: "auto",
 							Bucket: config.RepoRef{
@@ -484,7 +364,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1-pre.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -501,20 +381,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
-						Release: config.Release{
-							GitHub: config.Repo{
-								Owner: "test",
-								Name:  "test",
-							},
-						},
 						Scoop: config.Scoop{
 							SkipUpload: "true",
 							Bucket: config.RepoRef{
@@ -529,7 +396,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1-pre.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -546,14 +413,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "tar.gz"},
-						},
 						Release: config.Release{
 							Disable: true,
 						},
@@ -570,7 +430,7 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
+				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
 			},
 			shouldNotErr,
@@ -587,17 +447,7 @@ func Test_doRun(t *testing.T) {
 					},
 					Version: "1.0.1",
 					Config: config.Project{
-						Builds: []config.Build{
-							{Binary: "test", Goarch: []string{"amd64"}, Goos: []string{"windows"}},
-						},
-						Dist:        ".",
 						ProjectName: "run-pipe",
-						Archives: []config.Archive{
-							{Format: "binary"},
-						},
-						Release: config.Release{
-							Draft: true,
-						},
 						Scoop: config.Scoop{
 							Bucket: config.RepoRef{
 								Owner: "test",
@@ -610,11 +460,8 @@ func Test_doRun(t *testing.T) {
 				},
 				client.NewMock(),
 			},
-			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Path: file},
-				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
-			},
-			shouldErr("archive format is binary"),
+			[]artifact.Artifact{},
+			shouldErr(ErrNoWindows.Error()),
 			shouldNotErr,
 			noAssertions,
 		},
@@ -659,11 +506,7 @@ func Test_buildManifest(t *testing.T) {
 					GitHubURLs: config.GitHubURLs{
 						Download: "https://github.com",
 					},
-					Dist:        ".",
 					ProjectName: "run-pipe",
-					Archives: []config.Archive{
-						{Format: "tar.gz"},
-					},
 					Release: config.Release{
 						GitHub: config.Repo{
 							Owner: "test",
@@ -696,11 +539,7 @@ func Test_buildManifest(t *testing.T) {
 					GitHubURLs: config.GitHubURLs{
 						Download: "https://github.com",
 					},
-					Dist:        ".",
 					ProjectName: "run-pipe",
-					Archives: []config.Archive{
-						{Format: "tar.gz"},
-					},
 					Release: config.Release{
 						GitHub: config.Repo{
 							Owner: "test",
@@ -735,20 +574,7 @@ func Test_buildManifest(t *testing.T) {
 					GitHubURLs: config.GitHubURLs{
 						Download: "https://github.com",
 					},
-					Builds: []config.Build{
-						{Binary: "test"},
-					},
-					Dist:        ".",
 					ProjectName: "run-pipe",
-					Archives: []config.Archive{
-						{Format: "tar.gz"},
-					},
-					Release: config.Release{
-						GitHub: config.Repo{
-							Owner: "test",
-							Name:  "test",
-						},
-					},
 					Scoop: config.Scoop{
 						Bucket: config.RepoRef{
 							Owner: "test",
@@ -777,20 +603,7 @@ func Test_buildManifest(t *testing.T) {
 					GitLabURLs: config.GitLabURLs{
 						Download: "https://gitlab.com",
 					},
-					Builds: []config.Build{
-						{Binary: "test"},
-					},
-					Dist:        ".",
 					ProjectName: "run-pipe",
-					Archives: []config.Archive{
-						{Format: "tar.gz"},
-					},
-					Release: config.Release{
-						GitHub: config.Repo{
-							Owner: "test",
-							Name:  "test",
-						},
-					},
 					Scoop: config.Scoop{
 						Bucket: config.RepoRef{
 							Owner: "test",
@@ -815,13 +628,15 @@ func Test_buildManifest(t *testing.T) {
 
 			cl, err := client.New(ctx)
 			require.NoError(t, err)
+			require.NoError(t, Pipe{}.Default(ctx))
 
 			mf, err := dataFor(ctx, cl, []*artifact.Artifact{
 				{
-					Name:   "foo_1.0.1_windows_amd64.tar.gz",
-					Goos:   "windows",
-					Goarch: "amd64",
-					Path:   file,
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
 					Extra: map[string]interface{}{
 						artifact.ExtraBuilds: []*artifact.Artifact{
 							{
@@ -884,12 +699,6 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 		Version:   "1.0.1",
 		Artifacts: artifact.New(),
 		Config: config.Project{
-			Archives: []config.Archive{
-				{Format: "tar.gz"},
-			},
-			Builds: []config.Build{
-				{Binary: "test"},
-			},
 			Dist:        folder,
 			ProjectName: "run-pipe",
 			Scoop: config.Scoop{
@@ -907,11 +716,24 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 	path := filepath.Join(folder, "bin.tar.gz")
 
 	ctx.Artifacts.Add(&artifact.Artifact{
-		Name:   "bin.tar.gz",
-		Path:   path,
-		Goos:   "windows",
-		Goarch: "amd64",
-		Type:   artifact.UploadableArchive,
+		Name:    "bin.tar.gz",
+		Path:    path,
+		Goos:    "windows",
+		Goarch:  "amd64",
+		Goamd64: "v1",
+		Type:    artifact.UploadableArchive,
+		Extra: map[string]interface{}{
+			artifact.ExtraID:     "foo",
+			artifact.ExtraFormat: "tar.gz",
+		},
+	})
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name:    "ignored.tar.gz",
+		Path:    path,
+		Goos:    "windows",
+		Goarch:  "amd64",
+		Goamd64: "v3",
+		Type:    artifact.UploadableArchive,
 		Extra: map[string]interface{}{
 			artifact.ExtraID:     "foo",
 			artifact.ExtraFormat: "tar.gz",
@@ -931,6 +753,7 @@ func TestRunPipeScoopWithSkipUpload(t *testing.T) {
 	require.NoError(t, f.Close())
 
 	cli := client.NewMock()
+	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, doRun(ctx, cli))
 	require.EqualError(t, doPublish(ctx, cli), `scoop.skip_upload is true`)
 
@@ -954,20 +777,7 @@ func TestWrapInDirectory(t *testing.T) {
 			GitLabURLs: config.GitLabURLs{
 				Download: "https://gitlab.com",
 			},
-			Builds: []config.Build{
-				{Binary: "test"},
-			},
-			Dist:        ".",
 			ProjectName: "run-pipe",
-			Archives: []config.Archive{
-				{Format: "tar.gz", WrapInDirectory: "true"},
-			},
-			Release: config.Release{
-				GitHub: config.Repo{
-					Owner: "test",
-					Name:  "test",
-				},
-			},
 			Scoop: config.Scoop{
 				Bucket: config.RepoRef{
 					Owner: "test",
@@ -986,10 +796,11 @@ func TestWrapInDirectory(t *testing.T) {
 	require.NoError(t, err)
 	mf, err := dataFor(ctx, cl, []*artifact.Artifact{
 		{
-			Name:   "foo_1.0.1_windows_amd64.tar.gz",
-			Goos:   "windows",
-			Goarch: "amd64",
-			Path:   file,
+			Name:    "foo_1.0.1_windows_amd64.tar.gz",
+			Goos:    "windows",
+			Goarch:  "amd64",
+			Goamd64: "v1",
+			Path:    file,
 			Extra: map[string]interface{}{
 				artifact.ExtraWrappedIn: "foo_1.0.1_windows_amd64",
 				artifact.ExtraBuilds: []*artifact.Artifact{
