@@ -255,7 +255,7 @@ func TestRun(t *testing.T) {
 		unis := ctx1.Artifacts.Filter(artifact.ByType(artifact.UniversalBinary)).List()
 		require.Len(t, unis, 1)
 		checkUniversalBinary(t, unis[0])
-		require.True(t, unis[0].Extra[artifact.ExtraReplaces].(bool))
+		require.True(t, artifact.ExtraOr(*unis[0], artifact.ExtraReplaces, false))
 	})
 
 	t.Run("keeping", func(t *testing.T) {
@@ -264,7 +264,7 @@ func TestRun(t *testing.T) {
 		unis := ctx2.Artifacts.Filter(artifact.ByType(artifact.UniversalBinary)).List()
 		require.Len(t, unis, 1)
 		checkUniversalBinary(t, unis[0])
-		require.False(t, unis[0].Extra[artifact.ExtraReplaces].(bool))
+		require.False(t, artifact.ExtraOr(*unis[0], artifact.ExtraReplaces, true))
 	})
 
 	t.Run("bad template", func(t *testing.T) {
